@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0007';
+our $VERSION = '0.0008';
 
 use Moo;
 use strictures 2;
@@ -136,7 +136,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0007
+version 0.0008
 
 =head1 SYNOPSIS
 
@@ -152,12 +152,15 @@ version 0.0007
   my $setting = $synth->recall_setting(id => $id1);
   # { etc => '...' }
 
-  my $settings = $synth->recall_settings(name => $name);
-  # [ 1 => { etc => '...' }, 2 => { etc => '???' } ]
+  # update the etc key only
+  $synth->make_setting(id => $id1, etc => '!!!');
 
   my $names = $synth->recall_names;
   # [ 'Foo!' ]
 
+  my $settings = $synth->recall_settings(name => $names->[0]);
+  # [ 1 => { etc => '!!!' }, 2 => { etc => '???' } ]
+
 =head1 DESCRIPTION
 
 C<Synth::Config> provides a way to save and recall synthesizer control
